@@ -23,7 +23,6 @@ from testtools import matchers
 from tempest.api.volume import base
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
-from tempest import test
 
 
 class VolumesListTestJSON(base.BaseVolumeTest):
@@ -47,7 +46,7 @@ class VolumesListTestJSON(base.BaseVolumeTest):
             fetched_list = [fieldsgetter(item) for item in fetched_list]
 
         missing_vols = [v for v in expected_list if v not in fetched_list]
-        if len(missing_vols) == 0:
+        if not missing_vols:
             return
 
         def str_vol(vol):
@@ -99,7 +98,7 @@ class VolumesListTestJSON(base.BaseVolumeTest):
                     else:
                         self.assertEqual(params[key], volume[key], msg)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     @decorators.idempotent_id('0b6ddd39-b948-471f-8038-4787978747c4')
     def test_volume_list(self):
         # Get a list of Volumes
@@ -344,7 +343,7 @@ class VolumesListTestJSON(base.BaseVolumeTest):
 
             # If cannot follow make sure it's because we have finished
             else:
-                self.assertEqual([], remaining or [],
+                self.assertEmpty(remaining or [],
                                  'No more pages reported, but still '
                                  'missing ids %s' % remaining)
                 break
