@@ -41,15 +41,10 @@ class TestServerAdvancedOps(manager.ScenarioTest):
         cls.set_network_resources()
         super(TestServerAdvancedOps, cls).setup_credentials()
 
-    @test.attr(type='slow')
+    @decorators.attr(type='slow')
     @decorators.idempotent_id('e6c28180-7454-4b59-b188-0257af08a63b')
     @testtools.skipUnless(CONF.compute_feature_enabled.resize,
                           'Resize is not available.')
-    @testtools.skipUnless(CONF.compute.flavor_ref !=
-                          CONF.compute.flavor_ref_alt
-                          and CONF.compute.flavor_ref_alt != "",
-                          'The flavor_ref_alt option should not be empty and '
-                          'should not be identical with flavor_ref')
     @test.services('compute', 'volume')
     def test_resize_volume_backed_server_confirm(self):
         # We create an instance for use in this test
@@ -68,7 +63,7 @@ class TestServerAdvancedOps(manager.ScenarioTest):
         waiters.wait_for_server_status(self.servers_client, instance_id,
                                        'ACTIVE')
 
-    @test.attr(type='slow')
+    @decorators.attr(type='slow')
     @decorators.idempotent_id('949da7d5-72c8-4808-8802-e3d70df98e2c')
     @testtools.skipUnless(CONF.compute_feature_enabled.suspend,
                           'Suspend is not available.')
